<?php

namespace Drupal\file_table_formatter;

use Drupal\Core\Field\EntityReferenceFieldItemListInterface;
use Drupal\file\Entity\File;
use Drupal\file\Plugin\Field\FieldType\FileItem;

class FileTableData {

  /**
   * @var \Drupal\file\Entity\File
   */
  protected $file;

  /**
   * @var \Drupal\Core\Field\EntityReferenceFieldItemListInterface
   */
  protected $item;

  /**
   * @var mixed[]|null
   */
  protected $header;

  /**
   * @var mixed[]
   */
  protected $rows;

  /**
   * @var string|null
   */
  protected $title;

  /**
   * FileTableData constructor.
   *
   * @param \Drupal\file\Entity\File $file
   * @param \Drupal\file\Plugin\Field\FieldType\FileItem $item
   * @param mixed[] $rows
   * @param mixed[]|null $header
   * @param string $title
   */
  public function __construct(File $file, FileItem $item = NULL, array $rows = NULL, array $header = NULL, $title = NULL) {
    $this->file = $file;
    $this->item = $item;
    $this->header = $header;
    $this->rows = $rows;
    $this->title = $title;
  }

  /**
   * @return \Drupal\file\Entity\File
   */
  public function getFile(): File {
    return $this->file;
  }

  /**
   * @return \Drupal\Core\Field\EntityReferenceFieldItemListInterface
   */
  public function getItem(): EntityReferenceFieldItemListInterface {
    return $this->item;
  }

  /**
   * @return mixed[]
   */
  public function getHeader(): ?array {
    return $this->header;
  }

  /**
   * @return mixed[]
   */
  public function getRows(): array {
    return $this->rows;
  }

  /**
   * @return string|null
   */
  public function getTitle(): ?string {
    return $this->title;
  }

}
