<?php

namespace Drupal\file_table_formatter;

use Drupal\file\Entity\File;

class FileTableFormatterProcessor implements FileTableFormatterProcessorInterface {

  /**
   * {@inheritdoc}
   */
  public function getTableDataFromFile(File $file, bool $includes_header = FALSE, ?string $text_format = NULL): FileTableData {
    $data = [];

    // Currently only supports CSV files
    if ($file->getMimeType() == 'text/csv') {
      // Read the file
      if (($fhandle = fopen($file->getFileUri(), 'r')) !== FALSE) {
        while ($row = fgetcsv($fhandle)) {
          foreach ($row as &$col) {
            if (!empty($text_format)) {
              $col = [
                'data' => [
                  '#type' => 'processed_text',
                  '#text' => $col,
                  '#format' => $text_format,
                ],
              ];
            }
          }
          $data[] = $row;
        }
        fclose($fhandle);
      }
    }
    
    $item = NULL;
    $header = NULL;
    $rows = NULL;
    $title = NULL;
    
    if (!empty($file->_referringItem)) {
      $item = $file->_referringItem;
      $title = !empty($file->_referringItem->description) ? $file->_referringItem->description : NULL;
    }
    if (!empty($data)) {
      // Handle header.
      if ($includes_header) {
        $header = array_shift($data);
      }
      $rows = $data;
    }
    return new FileTableData($file, $item, $rows, $header, $title);
  }

}
